#
# spec file for package squidGuard
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sg_dbhome %{_localstatedir}/lib/squidGuard/db
%define sg_logdir %{_localstatedir}/log/squidGuard
%define sg_config %{_sysconfdir}/squidguard.conf
%define cgidir    /srv/www/cgi-bin
%define imgdir    /srv/www/htdocs/images
%define uname     maintain_squidguard-upstream
Name:           squidGuard
Version:        1.6.0
Release:        2.4
Summary:        Filter plugin for squid
License:        GPL-2.0-only
Group:          Productivity/Networking/Web/Proxy
URL:            http://www.squidguard.org/
# GIT-CLONE:    https://salsa.debian.org/joowie-guest/maintain_squidguard
Source0:        https://salsa.debian.org/joowie-guest/maintain_squidguard/-/archive/upstream/%{version}/%{uname}-%{version}.tar.bz2
Source1:        README.SUSE
Source2:        squidGuard.logrotate
Source3:        blocked.gif
Patch0:         squidGuard-mysql.patch
Patch1:         squidGuard-config.patch
Patch2:         default_config_pathfixes.patch
Patch3:         config_exit.patch
Patch4:         types.patch
BuildRequires:  bison
BuildRequires:  db-devel
BuildRequires:  flex
BuildRequires:  gettext
BuildRequires:  grep
BuildRequires:  libmysqlclient-devel
BuildRequires:  libtool
BuildRequires:  openldap2-devel
Requires:       http_proxy
Requires(pre):  http_proxy
Recommends:     logrotate
Recommends:     lynx

%description
SquidGuard is a filter, redirector, and access controller plugin for squid.
It lets you define multiple access rules with different restrictions for
different user groups on a squid cache. SquidGuard uses squid's standard
redirector interface.

%package doc
Summary:        Documentation and examples for squidGuard
Group:          Documentation/Other

%description doc
This package contains documentation for SquidGuard, a filter, redirector,
and access controller plugin for squid.

%prep
%autosetup -p1 -n %{uname}-%{version}
cp %{SOURCE1} .
# patch the test configs
pushd test 1>/dev/null
for i in test*.conf.in; do
	sed "s|logdir @TESTDIR@|logdir %{sg_logdir}|; \
		 s|dbhome @TESTDIR@|dbhome %{sg_dbhome}|" $i > $i.tmp
	mv -v $i.tmp $i
done

%build
export CFLAGS="%{optflags} -fcommon"
./autogen.sh
%configure \
	--with-squiduser=squid \
	--with-mysql \
	--with-nolog=yes \
	--with-db-inc=%{_includedir}/db4 \
	--with-sg-config=%{sg_config} \
	--with-sg-dbhome=%{sg_dbhome} \
	--with-sg-logdir=%{sg_logdir} \
	--with-ldap
%make_build
pushd contrib
%make_build
popd

%install
mkdir %{buildroot}%{_sysconfdir}
%make_install
# fix install dir
if [ -f %{buildroot}/%{_bindir}/squidGuard ]; then
	mkdir -p %{buildroot}/%{_sbindir}
	install -m755 %{buildroot}/%{_bindir}/squidGuard  %{buildroot}/%{_sbindir}/
	rm -rf %{buildroot}/%{_bindir}
fi
# install blacklist
mkdir -p %{buildroot}%{_localstatedir}/lib/squidGuard/db/blacklist
install -m 644 test/blacklist/* %{buildroot}%{_localstatedir}/lib/squidGuard/db/blacklist
# install cgi
mkdir -p %{buildroot}/%{cgidir}
mkdir -p %{buildroot}/%{imgdir}
install -m755 samples/*.cgi  %{buildroot}/%{cgidir}/
install -m644 samples/babel* %{buildroot}/%{cgidir}/
install -m644 %{SOURCE3}         %{buildroot}/%{imgdir}/blocked.gif
# prepare logdir
mkdir -p %{buildroot}%{sg_logdir}
# prepare logrotate
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d
sed "s|@SG_LOGDIR@|%{sg_logdir}|g" %{SOURCE2} > %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
# clean up
rm -f {contrib,doc,samples,test}/{Makefile,*.in,*/*.in,.*.swp}
# install docu
mkdir -p %{buildroot}/%{_defaultdocdir}/%{name}
cp -r {contrib,doc,samples,test} %{buildroot}/%{_defaultdocdir}/%{name}/
cp ANNOUNCE CHANGELOG FAQ README* %{buildroot}/%{_defaultdocdir}/%{name}/

%files
%license GPL COPYING
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/ANNOUNCE
%doc %{_defaultdocdir}/%{name}/CHANGELOG
%doc %{_defaultdocdir}/%{name}/FAQ
%doc %{_defaultdocdir}/%{name}/README*
%attr(770, squid, squid) %dir %{_localstatedir}/lib/squidGuard
%attr(770, squid, squid) %dir %{sg_dbhome}
%attr(770, squid, squid) %dir %{sg_logdir}
%config(noreplace) %attr(660, squid, squid) %{sg_config}
%dir %attr(770, squid, squid) %{_localstatedir}/lib/squidGuard/db/blacklist
%config(noreplace) %attr(660, squid, squid) %{_localstatedir}/lib/squidGuard/db/blacklist/*
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_sbindir}/*
%dir /srv/www
%dir /srv/www/htdocs
%dir %{imgdir}
%dir %{cgidir}
%{cgidir}/*
%{imgdir}/*

%files doc
%license GPL COPYING
%doc %{_defaultdocdir}/%{name}/contrib
%doc %{_defaultdocdir}/%{name}/doc
%doc %{_defaultdocdir}/%{name}/samples
%doc %{_defaultdocdir}/%{name}/test

%changelog
* Thu Nov  7 2024 Adam Majer <adam.majer@suse.de>
- config_exit.patch: fix build failure due to undefined exit() in
  configure.ac scripts
- types.patch: fix types in mysql types
* Wed Apr 28 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to debian maintained version 1.6.0:
  * Add support for IPv6 protocol (as in squid 3.x)
  * Bugfix: Convert special characters to fix XSS security problem.
  * Move text files to UTF-8 format.
  * Fix for missing content after percent sign
  * Fix for working (only) with squid 3.4 and higher.
- Update to debian maintained version 1.5.1
  * Updated links in documentation and sample files.
  * Use newer OpenLDAP search
  * Enable 'ldap deprecated' flag.
- Update to debian maintained version 1.5.0
  * Fixed a problem with Berkeley DB 5.x
  * Fixed inconsistent blocking.
  * Added Russian translation to squidGuard.cgi.in
  * Added a feature to send log messages to syslog
  * Anonymized passwords (for connecting to the ldap or mysql
    server) written to logfiles when squidGuard is starting.
  * Added patch to check IP addresses against LDAP.
  * Added patch to allow quoted strings in the configuration file
  * Fixed a problem with regular expressions.
  * Added patch to enable blocking against DNS based blacklists
- Update to debian maintained version 1.4.1
  * Fix of a bypass problem with URLs which length is close to
    the limit defined by MAX_BUF in squidGuard and MAX_URL in
    squid. Increasing the buffer limit to be higher than the one
    defined in MAX_URL solves the issue.
  * Fix of another bypass problem, which is related to the
    definition of these buffer limits.
  * Fix of one buffer overflow problem in sgLog.c when overlong
    URLs are requested
  * Fixes CVE-2009-3700, CVE-2009-3826 and CVE-2015-8936
- Refreshed squidGuard-config.patch
- Refreshed default_config_pathfixes.patch
- Refreshed and renamed squidGuard-1.4-mysql.patch
  to squidGuard-mysql.patch
- Dropped upstream fixed patches
  * xss_fix_02_2015.patch
  * squidGuard-CVE-2009-3826.patch
  * squidGuard-CVE-2009-3700.patch
  * squidGuard-1.4_upgrade.patch
  * squidGuard-Makefile.patch
  * type_fixes.patch
* Fri Jun 19 2020 Martin Pluskal <mpluskal@suse.com>
- Fix building with gcc10
* Mon Jul  8 2019 Martin Wilck <mwilck@suse.com>
- Use "su" directive in logrotate conf file (boo#1104856)
- Set user write permissions on /var/lib/squidGuard/db/blacklist
  (boo#1140722)
- Get rid of SysV init call in postrotate script
* Wed Feb 28 2018 mpluskal@suse.com
- Cleanup with spec-cleaner
* Wed Feb 28 2018 adam.majer@suse.de
- remove patches that modify generated code instead of template.
  They are already in the template and are unnedded.
  + squidGuard-trailing_dot.patch
  + squidGuard-unusual_url_end.patch
- update patches removing parts that update generated code
  + squidGuard-1.4_upgrade.patch
  + type_fixes.patch
- remove generated code before applying patches
- use SPDX 3.0 license and install it correctly
  squidGuard is GPL-2.0-only
* Thu Feb 15 2018 adam.majer@suse.de
- Enable LDAP support (bnc#1081012)
- type_fixes.patch: Actually define functions so use use correct
  pointer sizes on 64-bit arches once LDAP support is enabled.
- Minor specfile and description cleanup
- Fix building on SLE12 by removing useless BR: on lynx
* Wed Oct  4 2017 adam.majer@suse.de
- Merge SLE changes into Factory
* Thu Jun 29 2017 adam.majer@suse.de
- default_config_pathfixes.patch:
  reference only existing filter lists in default installed config
  (bnc#961499)
* Mon Jun 20 2016 adam.majer@suse.de
- add xss_fix_02_2015.patch:
  o fix XSS possibility in blocked error page by escaping all
    < and > in the printed url (CVE-2015-8936, bnc#985612)
- fix URL in README so it doesn't point at non-existent page
* Tue Mar 10 2015 ecsos@opensuse.org
- fix squid 3.4 error witch patch squidGuard-1.4_upgrade.patch
  see http://bugs.squid-cache.org/show_bug.cgi?id=3978 (bnc#1040757)
* Sat Mar  7 2015 ecsos@opensuse.org
- fix permissions for blacklist, conf, dbhome and logdir,
  so other tools like squidguardmanager can access
* Wed Sep 24 2014 pgajdos@suse.com
- SuSE -> SUSE [bnc#889003]
* Thu Oct 14 2010 puzel@novell.com
- fix squidGuard-CVE-2009-3826.patch patch
* Thu Jul 29 2010 puzel@novell.com
- add squidGuard-CVE-2009-3700.patch,
  squidGuard-CVE-2009-3826.patch (bnc#550930)
* Wed Jul 14 2010 ro@suse.de
- add "missingok" to logrotate configuration
  (no logfile if never used causing error from cron when
  running logrotate)
* Wed Oct 14 2009 chris@computersalat.de
- fixed deps for SLES_9
  o Unknown tag: Recommends:
* Sat Oct 10 2009 chris@computersalat.de
- fix deps
  o PreReq: http_proxy
  o osc meta -e prjconf Prefer: squid3
* Fri Oct  9 2009 chris@computersalat.de
- fixed lost mods from kssingvo 20070702
  o "Requires: http_proxy"  now, as squid3 is an alternative
- spec
  o sorted TAGS
- rpmlint
  o non-utf8-spec-file
* Sat Sep 26 2009 lrupp@suse.de
- update to 1.4:
  + some fixes
  + Added MySQL support for authentication. The database is
    assumed to be configured on localhost.
  + Fixed configure.in to comply with the autoconf standard
  + Fixed broken "make test"
  + Added new runtime parameter "-P". This parameter changes
    the default behaviour from stop (emergency mode) to pass
    when an error in building the database files occurs. So
    this parameter only works in connection with the runtime
    paramter "-C". Before using "-P" in your environment
    make sure that nothing breakes when the building of the
    db files fail.
  + Added Spanish translation to squidGuard.cgi
- enabled --nolog option
- enabled mysql auth
- removed squidGuard-1.3-bl_less_noise.patch (upstream)
- adapted squidGuard-1.3-config.patch
- split up doc package
- package the cgi scripts (and babel files) in /srv/www/cgi-bin
- package blocked.gif in /srv/www/htdocs/images
- added squidGuard.logrotate script
* Tue Jul 22 2008 kssingvo@suse.de
- added latest upstream patch (20080714) as two individual patches:
  * fix for squid complaining about progress bar
  * fix if URL was requested which ends with "://"
* Wed Jul  2 2008 kssingvo@suse.de
- added latest upstream patch (20080613) as trailing_dot.patch
- "Requires: http_proxy"  now, as squid3 is an alternative
* Thu Nov 29 2007 kssingvo@suse.de
- update to version 1.3:
  * Included configurable logging. New configure option --nolog
    suppress all runtime logmessages. Start and stop is still
    logged. Default behaviour is now to log the non debug
    messages except when the runtime option -d is supplied to
    squidGuard. May need some more finetuning in later versions.
    (bug 11) Made some slight changes to the outdated FAQ file.
  * Modified auth code to work with and without ldap (choosing
    subroutine rfc1738_unescape or sgFindUser in sg.y.in)
  * Corrected include statement in sg.h.in.
  * Added patch by Marc Clayton to include a progressbar to the
    build of the database files (bug 6).
  * Added patch by Eric Harrison to enable full sed compliance to
    rewrite statements (bug 7).
  * Corrected missing evaluation of configure parameters for
    logdir, dbhome and config file (bug 11).
  * Added patch from satish to block urls entries that include
    hostnames (bug 4).
  * Fixed broken regex evaluation (bug 12)
  * Fixed a compile problem on some systems (bug 10).
  * Corrected an issue with the fix for the double slash
    vulnerability (incorrectly found double slashes) (bug 1).
- fixed build/config issues
* Wed Jul  4 2007 kssingvo@suse.de
- fixes from upstream:
  * double slash bug fix extracted from Patch-20070513 tarball
  * regexp bug fix extracted from Patch-20070520 tarball
  * compiler bug fix extracted from Patch-20070520 tarball
* Thu May 10 2007 kssingvo@suse.de
- upgrade to version 1.2.1:
  * Fixed multiple slash bypass vulnerabilty.
  * Fixed some bugs in squidGuard-simple.cgi and added a
    German version of it.
  * Fixed encoding bypass vulnerabilty.
  * Updated y.tab.c.bison and y.tab.h.bison to the recent version.
  * Fixed bug in user authentication.
  * Fixed some typos which broke compilation on Sun Solaris
    when using the Sun CC compiler.
  * Corrected unproper evaluated if-clause, which broke the
    BerkeleyDB 2 compatibility.
  * Fixed minor typo in samples/Makefile.in.
  * Replaced the sleepycat links from the configure program with
    the oracle links.
  * Corrected typo in Makefile.in.
  * Removed a stupid bug from the Makefile in the docs directory.
  * Removed references to squidguard.org in Makefile.in in the
    Doc directory (squidguard.org is down).
  * Added ISSUES.txt file about known problem with the current
    code (any information that is missing and should go in there
    is gladly welcomed).
  * Release now supports LDAP queries for authentication:
  * Added Chris Frey's ldap patches and fixes (03, 05, 06,
    07 and 10; Patches from:
    http://www.netdirect.ca/software/category.php?cat=SquidGuard).
  * The LDAP feature can be included during the configure run
    by setting --with-ldap.
  * Added a fix provided by Francesco Ranieri to solve an issue
    with the (un)escaping of the authentication "domain%%5cusername".
- adapted configuration related patches
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Tue Nov  8 2005 dmueller@suse.de
- don't build as root
* Wed Apr 28 2004 ro@suse.de
- added -fno-strict-aliasing
* Wed Jun 25 2003 kssingvo@suse.de
- fixed db->open() call, like Thorsten suggested
* Tue Feb  4 2003 kssingvo@suse.de
- made pathes FHS 2.2 clean
* Thu Aug  1 2002 kssingvo@suse.de
- added README.SuSE (as suggest in bugzilla #16670)
* Mon Jul  8 2002 kukuk@suse.de
- Fix to build without existing squid user
- Add squid to PreRequires.
* Tue Jun 25 2002 ro@suse.de
- fix directory permissions
* Wed Jan  9 2002 ro@suse.de
- use db package (update to 1.2.0 to make it compile)
* Wed Sep 26 2001 bjacke@suse.de
- use buildroot
- correct permissions in /var/squidGuard
- rename squigrd -> squidGuard
* Tue Apr 10 2001 ro@suse.de
- added group tag
* Wed Jun 28 2000 bodammer@suse.de
- installing a useable test configuration
* Fri Jun 23 2000 bodammer@suse.de
- initial package of squidGuard Version 1.1.4
